@@ -38,6 +38,9 @@ static const char rcsid[] = "$Id: sub-func.c,v 1.28 2003/03/19 12:28:15 simius E
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -70,7 +73,6 @@ validate_v4addr (char *addr)
 {
 	int x, y, z, m;
 	char buf[16];
-	char *sl;
 
 	if (strlen (addr) < 7 || strlen (addr) > 15)
 		return 0;
@@ -140,7 +142,6 @@ int
 validate_netmask (char *in_addr)
 {
 	int x, y, z, m;
-	char buf[16];
 	char addr[16];
 	char *sl;
 	u_int32_t sm;
@@ -284,7 +285,6 @@ int
 getsplitnumv6 (char *buf, struct sip_in6_addr *splitmask, int *v6splitnum)
 {
 	int x, y;
-	u_int32_t sm;
 
 	if (strlen (buf) < 1)
 		return -1;
@@ -848,7 +848,6 @@ v6addrtonum (struct ipv6_split spstr, struct v6addr *in6_addr, int type)
 	int colon;
 	int x, y, z, n;
 	char buf[128];
-	u_int32_t num;
 
 	colon = 0;
 	if (type == V6TYPE_STANDARD)
@@ -935,7 +934,7 @@ v6masktonum (char *nmask, int *nmaskbits, struct sip_in6_addr *in6_addr)
 int
 validate_v6addr (char *addr)
 {
-	int x, y, z;
+	int x;
 	struct ipv6_split spstr;
 
 	bzero ((char *) spstr.ipv6addr, 40);
@@ -1315,7 +1314,6 @@ _resolv_v6_gai (char *raddr, struct dnsresp *d_resp, char *extra)
 	int x;
 	struct addrinfo hints;
 	struct addrinfo *res, *res_orig;
-	struct sockaddr_in *sin;
 	struct sockaddr_in6 *sin6;
 	static char retaddr[1024];
 	char ip6addr[128];
