@@ -139,7 +139,7 @@ show_split_networks_v4 (struct if_info *ifi, u_int32_t splitmask, int v4args, st
 			bzero ((char *) ifi_tmp.p_v4nmask, 16);
 			bzero ((char *) ifi_tmp.p_v6addr, 44);
 			snprintf (ifi_tmp.p_v4addr, 19, "%s", numtoquad (start));
-			snprintf (ifi_tmp.p_v4nmask, 16, numtoquad (splitmask));
+			snprintf (ifi_tmp.p_v4nmask, 16, "%s", numtoquad (splitmask));
 		}
 		start += diff;
 		if (end == 0xffffffff || end >= ifi->v4ad.n_broadcast)
