@@ -137,7 +137,7 @@ out_cmdline (struct if_info *ifarg_cur, int v4args, struct misc_args m_argv4,
 	}
 
 	return 0;
-};
+}
 
 int
 cleanline (char *sbuf, char *dbuf)
@@ -550,7 +550,7 @@ parse_abox (struct argbox *abox, struct if_info *if_start)
 			if (!if_found) {
 				strncpy (ifarg_cur->name, abox->str, IFNAMSIZ);
 				strncpy (ifarg_cur->cmdstr, abox->str, 127);
-				snprintf(ifarg_cur->errorstr, 127, "Unable to retrieve interface information");
+				snprintf(ifarg_cur->errorstr, sizeof(ifarg_cur->errorstr), "Unable to retrieve interface information");
 				ifarg_cur->type = IFT_INTV4;
 			}
 		}
@@ -574,7 +574,7 @@ parse_abox (struct argbox *abox, struct if_info *if_start)
 			if (!if_found) {
 				strncpy (ifarg_cur->name, abox->str, IFNAMSIZ);
 				strncpy (ifarg_cur->cmdstr, abox->str, 127);
-				snprintf(ifarg_cur->errorstr, 127, "Unable to retrieve interface information");
+				snprintf(ifarg_cur->errorstr, sizeof(ifarg_cur->errorstr), "Unable to retrieve interface information");
 				ifarg_cur->type = IFT_INTV4;
 			}
 		}
@@ -638,7 +638,7 @@ parse_abox (struct argbox *abox, struct if_info *if_start)
 				}
 				if (!if_found) {
 					strncpy (ifarg_cur->cmdstr, abox->str, 127);
-					snprintf(ifarg_cur->errorstr, 127, "Unparsable argument.");
+					snprintf(ifarg_cur->errorstr, sizeof(ifarg_cur->errorstr), "Unparsable argument.");
 					ifarg_cur->type = IFT_UNKWN;
 				}
 
